==> mdm-rpc-0.0.31-sources.jar: com/chinayanghe/msp/mdm/vo/position/PositionProductVo.java <==
package com.chinayanghe.msp.mdm.vo.position;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by danDy on 2017/5/3.
 */
public class PositionProductVo implements Serializable {
    private static final long serialVersionUID = 70841586554549961L;
    //主键
    private String id;
    //岗位编码
    private String positionCode;
    //物料编码
    private String productCode;
    //创建时间
    private Date createDate;
    //创建人
    private String createName;
    //最新更新时间
    private Date updateDate;
    //最新更新人
    private String updateName;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }
}

==> mdm-rpc-0.1.8-sources.jar: com/chinayanghe/msp/mdm/vo/position/PositionProductVo.java <==
package com.chinayanghe.msp.mdm.vo.position;

import java.util.Date;

/**
 * Created by danDy on 2017/5/3.
 */
public class PositionProductVo {
    //主键
    private String id;
    //岗位编码
    private String positionCode;
    //物料编码
    private String productCode;
    //创建时间
    private Date createDate;
    //创建人
    private String createName;
    //最新更新时间
    private Date updateDate;
    //最新更新人
    private String updateName;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }
}
